@@ -619,7 +619,7 @@ class install_convert extends module
 	{
 		global $template, $user, $phpbb_root_path, $phpEx, $db, $lang, $config, $cache, $auth;
 		global $convert, $convert_row, $message_parser, $skip_rows, $language;
-		global $request, $phpbb_config_php_file;
+		global $request, $phpbb_config_php_file, $phpbb_dispatcher;
 
 		extract($phpbb_config_php_file->get_all());
 
@@ -796,7 +796,7 @@ class install_convert extends module
 		}
 
 		$error = false;
-		$convert->fulltext_search = new $search_type($error, $phpbb_root_path, $phpEx, $auth, $config, $db, $user);
+		$convert->fulltext_search = new $search_type($error, $phpbb_root_path, $phpEx, $auth, $config, $db, $user, $phpbb_dispatcher);
 
 		if ($error)
 		{
@@ -932,7 +932,7 @@ class install_convert extends module
 								$val = array($val);
 							}
 
-							for ($j = 0; $j < sizeof($val); ++$j)
+							for ($j = 0, $size = sizeof($val); $j < $size; ++$j)
 							{
 								if (preg_match('/LEFT JOIN ([a-z0-9_]+) AS ([a-z0-9_]+)/i', $val[$j], $m))
 								{
